import { PdfFile } from '../../types/drawing.ts'
import { CurrentUserMark } from '../../types/mark.ts'
import PdfPageItem from './PdfPageItem.tsx'

interface PdfItemProps {
  pdfFile: PdfFile
  currentUserMarks: CurrentUserMark[]
  handleMarkClick: (id: number) => void
  selectedMarkValue: string
  selectedMark: CurrentUserMark | null
}

/**
 * Responsible for displaying pages of a single Pdf File.
 */
const PdfItem = ({
  pdfFile,
  currentUserMarks,
  handleMarkClick,
  selectedMarkValue,
  selectedMark
}: PdfItemProps) => {
  const filterByPage = (
    marks: CurrentUserMark[],
    page: number
  ): CurrentUserMark[] => {
    return marks.filter((m) => m.mark.location.page === page)
  }
  return pdfFile.pages.map((page, i) => {
    return (
      <PdfPageItem
        page={page}
        key={i}
        currentUserMarks={filterByPage(currentUserMarks, i)}
        handleMarkClick={handleMarkClick}
        selectedMarkValue={selectedMarkValue}
        selectedMark={selectedMark}
      />
    )
  })
}

export default PdfItem
